#ifdef DVP7010ADLL_EXPORTS
#define DVP7010ADLL_API __declspec(dllexport)
#else
#define DVP7010ADLL_API __declspec(dllimport)
#endif


#define ID_NEW_FRAME 37810
#define ID_MUX0_NEW_FRAME 37800
#define ID_MUX1_NEW_FRAME 37801
#define ID_MUX2_NEW_FRAME 37802
#define ID_MUX3_NEW_FRAME 37803

const BYTE HOURLY_ALARM		= 0x0;
const BYTE DAILY_ALARM		= 0x2;
const BYTE WEEKLY_ALARM		= 0x6;
const BYTE MONTHLY_ALARM	= 0xa;
const BYTE YEARLY_ALARM		= 0x1a;
const BYTE ONCE_ALARM		= 0x3a;

typedef enum
{
	SUCCEEDED		= 1,
	FAILED			= 0,
	SDKINITFAILED	= -1,
	PARAMERROR		= -2,
	BOARDIDERROR	= -3,
	NOSAMPLE		= -5,
} Res;

typedef enum tagAnalogVideoFormat 
{
    Video_None       = 0x00000000,
    Video_NTSC_M     = 0x00000001, 
    Video_NTSC_M_J   = 0x00000002,  
    Video_PAL_B      = 0x00000010,
    Video_PAL_M      = 0x00000200,
    Video_PAL_N      = 0x00000400,
    Video_SECAM_B    = 0x00001000
} AnalogVideoFormat;

typedef enum tagColorFormat 
{
	RGB8=0,
	RGB16,
	RGB24,
	RGB32,
} ColorFormat;

typedef enum 
{
	SIZED1=0,
	SIZEVGA,
	SIZEQVGA,
	SIZESUBQVGA
} VideoSize;

typedef enum
{
	STOPPED			= 1,
	RUNNING			= 2,
	UNINITIALIZED	= -1,
	UNKNOWNSTATE	= -2,
} CapState;

typedef enum {
	BY_USER = 0,
	BY_ALARM,
	BY_TRIGGER0,
	BY_TRIGGER1
} POWERON_EVENT;

typedef struct{
	BYTE second;
	BYTE minute;
	BYTE hour;
	BYTE day;
	BYTE date;
	BYTE month;
	BYTE year;
} TimeStruct;

typedef struct{
	BOOL enable;
	BYTE type;
	TimeStruct AlarmT;
} AlarmStruct;

typedef struct{
	bool EnableWDT;
	bool EnableAlarm;
	bool EnableTrigger0;
	bool EnableTrigger1;
} UCFlag;

class DVP7010ADLL 
{
public:
	int Adv_DVPAPI_CreateSDKInstence(void **pp);
	virtual int Adv_DVPAPI_GetNoOfDevices() PURE;
	virtual int Adv_DVPAPI_InitSDK(int NoOfDevs, int* IDList) PURE;
	virtual int Adv_DVPAPI_CloseSDK() PURE;
	virtual int Adv_DVPAPI_Start(int BoardID, int SwitchingChans, HWND Main, HWND hwndPreview) PURE;
//	virtual int Adv_DVPAPI_Start(int BoardID, HWND Main, HWND hwndPreview) PURE;
	virtual int Adv_DVPAPI_Stop(int BoardID) PURE;
	virtual int Adv_DVPAPI_GetCapState(int BoardID) PURE;
//	virtual int Adv_DVPAPI_SnapShot(int BoardID, TCHAR fileName[MAX_PATH]) PURE;
	virtual int Adv_DVPAPI_GetCurFrameBuffer(int BoardID, int VMux, long* bufSize, BYTE* buf) PURE; 
	virtual int Adv_DVPAPI_SetNewFrameCallback(int BoardID, int callback) PURE;
	virtual int Adv_DVPAPI_GetVideoFormat(int BoardID, AnalogVideoFormat* vFormat) PURE;
	virtual int Adv_DVPAPI_SetVideoFormat(int BoardID, AnalogVideoFormat vFormat) PURE;
	virtual int Adv_DVPAPI_GetFrameRate(int BoardID, double *FrameRate) PURE;
	virtual int Adv_DVPAPI_SetFrameRate(int BoardID, double FrameRate) PURE;
	virtual int Adv_DVPAPI_GetResolution(int BoardID, VideoSize *Size) PURE; 
	virtual int Adv_DVPAPI_SetResolution(int BoardID, VideoSize Size) PURE; 
	virtual int Adv_DVPAPI_GetVideoInput(int BoardID, int* input) PURE;
	virtual int Adv_DVPAPI_SetVideoInput(int BoardID, int input) PURE;
	virtual int Adv_DVPAPI_GetColorFormat(int BoardID, int* colorformat) PURE;
	virtual int Adv_DVPAPI_SetColorFormat(int BoardID, int colorformat) PURE;
	virtual int Adv_DVPAPI_GetBrightness(int BoardID, long *pnValue) PURE;
	virtual int Adv_DVPAPI_SetBrightness(int BoardID, long nValue) PURE;
	virtual int Adv_DVPAPI_GetContrast(int BoardID, long *pnValue) PURE;
	virtual int Adv_DVPAPI_SetContrast(int BoardID, long nValue) PURE;
	virtual int Adv_DVPAPI_GetHue(int BoardID, long *pnValue) PURE;
	virtual int Adv_DVPAPI_SetHue(int BoardID, long nValue) PURE;
	virtual int Adv_DVPAPI_GetSaturation(int BoardID, long *pnValue) PURE;
	virtual int Adv_DVPAPI_SetSaturation(int BoardID, long nValue) PURE;
	virtual int Adv_DVPAPI_GPIOGetData(int BoardID, int Pin, BOOL* value) PURE;
	virtual int Adv_DVPAPI_GPIOSetData(int BoardID, int Pin, BOOL value) PURE;
	virtual int Adv_DVPAPI_GetWDTTimeout(int BoardID, BOOL *EnableWDT, int *timeout) PURE;
	virtual int Adv_DVPAPI_SetWDTTimeout(int BoardID, BOOL EnableWDT, int timeout) PURE;
	virtual int Adv_DVPAPI_GetUCFlag(int BoardID, BOOL *enableAlarm, BOOL *enableTrig0, BOOL *enableTrig1) PURE;
	virtual int Adv_DVPAPI_SetUCFlag(int BoardID, BOOL enableAlarm, BOOL enableTrig0, BOOL enableTrig1) PURE;
	virtual int Adv_DVPAPI_GetPoweronEvent(int BoardID, POWERON_EVENT *powerEvent) PURE;
	virtual int Adv_DVPAPI_GetAlarm(int BoardID, int index, AlarmStruct* alarm) PURE;
	virtual int Adv_DVPAPI_SetAlarm(int BoardID, int index, AlarmStruct* alarm) PURE;
	virtual int Adv_DVPAPI_GetChecksum(int BoardID, BYTE* key,BYTE *checksum) PURE;
	virtual int Adv_DVPAPI_GetEEData(int BoardID, BYTE wordAddr, BYTE* pData) PURE;
	virtual int Adv_DVPAPI_SetEEData(int BoardID, BYTE wordAddr, BYTE* pData) PURE;
	virtual int Adv_DVPAPI_GetRTCData(int BoardID, TimeStruct* time) PURE;
	virtual int Adv_DVPAPI_SetRTCData(int BoardID, TimeStruct* time) PURE;
};
